@@ -2,8 +2,6 @@
 
 from typing import Iterable
 
-import gaphor.C4Model.iconname  # noqa
-import gaphor.C4Model.propertypages  # noqa
 from gaphor.abc import ModelingLanguage
 from gaphor.C4Model import c4model, diagramitems
 from gaphor.C4Model.toolbox import c4model_diagram_types, c4model_toolbox_actions
@@ -25,7 +23,4 @@ class C4ModelLanguage(ModelingLanguage):
         yield from c4model_diagram_types
 
     def lookup_element(self, name):
-        element_type = getattr(c4model, name, None)
-        if not element_type:
-            element_type = getattr(diagramitems, name, None)
-        return element_type
+        return getattr(c4model, name, None) or getattr(diagramitems, name, None)
