@@ -5,6 +5,7 @@ from gaphor.core import transactional
 from gaphor.diagram.propertypages import (
     PropertyPageBase,
     PropertyPages,
+    handler_blocking,
     new_resource_builder,
 )
 from gaphor.UML.actions.activitynodes import DecisionNodeItem, ForkNodeItem
@@ -15,7 +16,6 @@ new_builder = new_resource_builder("gaphor.UML.actions")
 
 @PropertyPages.register(ObjectNodeItem)
 class ObjectNodePropertyPage(PropertyPageBase):
-
     order = 15
 
     ORDERING_VALUES = ["unordered", "ordered", "LIFO", "FIFO"]
@@ -69,7 +69,6 @@ class ObjectNodePropertyPage(PropertyPageBase):
 
 @PropertyPages.register(DecisionNodeItem)
 class DecisionNodePropertyPage(PropertyPageBase):
-
     order = 20
 
     def __init__(self, item):
@@ -93,7 +92,6 @@ class DecisionNodePropertyPage(PropertyPageBase):
 
 @PropertyPages.register(ForkNodeItem)
 class ForkNodePropertyPage(PropertyPageBase):
-
     order = 20
 
     def __init__(self, item):
@@ -126,7 +124,6 @@ class ForkNodePropertyPage(PropertyPageBase):
 
 @PropertyPages.register(UML.JoinNode)
 class JoinNodePropertyPage(PropertyPageBase):
-
     order = 15
 
     subject: UML.JoinNode
@@ -178,7 +175,6 @@ class FlowPropertyPageAbstract(PropertyPageBase):
         builder = new_builder(
             "transition-editor",
             signals={
-                "guard-changed": (self._on_guard_change,),
                 "transition-destroy": (self.watcher.unsubscribe_all,),
             },
         )
@@ -186,6 +182,7 @@ class FlowPropertyPageAbstract(PropertyPageBase):
         guard = builder.get_object("guard")
         guard.set_text(subject.guard or "")
 
+        @handler_blocking(guard, "changed", self._on_guard_change)
         def handler(event):
             v = event.new_value
             if v != guard.get_text():
