@@ -69,7 +69,13 @@ class FlowConnect(RelationshipConnect):
         )
 
         line.subject = relation
-        relation.activity = c1.subject.activity
+        if c1.subject.activity:
+            relation.activity = c1.subject.activity
+        elif isinstance(c1.subject, UML.OutputPin) and c1.subject.owner:
+            relation.activity = c1.subject.owner.activity  # type: ignore[attr-defined]
+        elif isinstance(c2.subject, UML.InputPin) and c2.subject.owner:
+            relation.activity = c2.subject.owner.activity  # type: ignore[attr-defined]
+
         opposite = line.opposite(handle)
         otc = self.get_connected(opposite)
         if (
@@ -155,10 +161,11 @@ class FlowForkDecisionNodeControlFlowConnect(FlowConnect):
             join_node = subject
 
             # determine flow class:
-            if any(f for f in join_node.incoming if isinstance(f, UML.ObjectFlow)):
-                flow_class: Type[UML.ActivityEdge] = UML.ObjectFlow
-            else:
-                flow_class = UML.ControlFlow
+            flow_class = (
+                UML.ObjectFlow
+                if any(f for f in join_node.incoming if isinstance(f, UML.ObjectFlow))
+                else UML.ControlFlow
+            )
 
             UML.recipes.swap_element(join_node, join_node_cls)
             fork_node: UML.ControlNode = element.model.create(fork_node_cls)
