@@ -3,7 +3,7 @@ import logging
 from gaphor import UML
 from gaphor.core import gettext
 from gaphor.core.modeling.properties import attribute
-from gaphor.core.styling import FontStyle, FontWeight, TextAlign, VerticalAlign
+from gaphor.core.styling import FontStyle, FontWeight, JustifyContent, TextAlign
 from gaphor.diagram.presentation import (
     Classified,
     ElementPresentation,
@@ -16,16 +16,15 @@ from gaphor.UML.classes.klass import (
     attributes_compartment,
     operation_watches,
     operations_compartment,
-    stereotype_compartments,
-    stereotype_watches,
 )
+from gaphor.UML.classes.stereotype import stereotype_compartments, stereotype_watches
 
 log = logging.getLogger(__name__)
 
 
 @represents(UML.Enumeration)
 class EnumerationItem(Classified, ElementPresentation[UML.Enumeration]):
-    """This item visualizes a Enumeration instance.
+    """This item visualizes an Enumeration instance.
 
     An EnumerationItem contains three compartments:
     1. Enumeration Literals
@@ -61,12 +60,21 @@ class EnumerationItem(Classified, ElementPresentation[UML.Enumeration]):
         "show_enumerations", int, default=True
     )
 
+    as_sysml_value_type: attribute[int] = attribute(
+        "as_sysml_value_type", int, default=False
+    )
+
     def update_shapes(self, event=None):
         self.shape = Box(
             Box(
                 Text(
                     text=lambda: UML.recipes.stereotypes_str(
-                        self.subject, [gettext("enumeration")]
+                        self.subject,
+                        [
+                            gettext("valueType")
+                            if self.as_sysml_value_type
+                            else gettext("enumeration")
+                        ],
                     ),
                 ),
                 Text(
@@ -104,7 +112,7 @@ class EnumerationItem(Classified, ElementPresentation[UML.Enumeration]):
             ),
             *(self.show_stereotypes and stereotype_compartments(self.subject) or []),
             style={
-                "vertical-align": VerticalAlign.TOP,
+                "justify-content": JustifyContent.START,
             },
             draw=draw_border,
         )
@@ -124,6 +132,10 @@ def enumerations_compartment(subject):
             )
             for literal in subject.ownedLiteral
         ),
-        style={"padding": (4, 4, 4, 4), "min-height": 8},
+        style={
+            "padding": (4, 4, 4, 4),
+            "min-height": 8,
+            "justify-content": JustifyContent.START,
+        },
         draw=draw_top_separator,
     )
