@@ -1,10 +1,20 @@
 """Support code for dealing with stereotypes in diagrams."""
 
 from gaphor.core.format import format
-from gaphor.core.styling import TextAlign, VerticalAlign
+from gaphor.core.styling import JustifyContent, TextAlign
 from gaphor.diagram.shapes import Box, Text, draw_top_separator
 
 
+def stereotype_watches(presentation):
+    presentation.watch("subject.appliedStereotype", presentation.update_shapes).watch(
+        "subject.appliedStereotype.classifier.name"
+    ).watch("subject.appliedStereotype.slot", presentation.update_shapes).watch(
+        "subject.appliedStereotype.slot.definingFeature.name"
+    ).watch(
+        "subject.appliedStereotype.slot.value", presentation.update_shapes
+    )
+
+
 def stereotype_compartments(subject):
     return filter(
         None,
@@ -36,7 +46,7 @@ def _create_stereotype_compartment(appliedStereotype):
             style={
                 "padding": (4, 4, 4, 4),
                 "min-height": 8,
-                "vertical-align": VerticalAlign.TOP,
+                "justify-content": JustifyContent.START,
             },
             draw=draw_top_separator,
         )
