@@ -19,16 +19,17 @@ bottom of the lifeline's lifetime when delete message is connected to a
 lifeline.
 """
 
-from gaphas.connector import Handle, Port
+from gaphas.connector import Handle
 from gaphas.constraint import CenterConstraint, EqualsConstraint, LessThanConstraint
 from gaphas.geometry import distance_line_point
-from gaphas.item import SE, SW
-from gaphas.position import MatrixProjection, Position
+from gaphas.item import NW, SE, SW
+from gaphas.port import LinePort
+from gaphas.position import MatrixProjection
 from gaphas.solver import VERY_STRONG, MultiConstraint
 from gaphas.solver.constraint import BaseConstraint
-from gaphas.types import Pos, SupportsFloatPos
 
 from gaphor import UML
+from gaphor.core.modeling.properties import attribute
 from gaphor.diagram.presentation import ElementPresentation, Named
 from gaphor.diagram.shapes import Box, Text, cairo_state, stroke
 from gaphor.diagram.support import represents
@@ -62,21 +63,9 @@ class BetweenConstraint(BaseConstraint):
             self.v.value = upper
 
 
-class BetweenPort(Port):
+class BetweenPort(LinePort):
     """Port defined as a line between two handles."""
 
-    def __init__(self, start: Position, end: Position) -> None:
-        super().__init__()
-
-        self.start = start
-        self.end = end
-
-    def glue(self, pos: SupportsFloatPos) -> tuple[Pos, float]:
-        d, pl = distance_line_point(
-            self.start.tuple(), self.end.tuple(), (float(pos[0]), float(pos[1]))
-        )
-        return pl, d
-
     def constraint(self, item, handle, glue_item):
         """Create connection line constraint between item's handle and the
         port."""
@@ -130,12 +119,6 @@ class LifetimeItem:
 
     min_length = property(lambda s: s._c_min_length.delta, _set_min_length)
 
-    def _set_connectable(self, connectable):
-        self.port.connectable = connectable
-        self.bottom.movable = connectable
-
-    connectable = property(lambda s: s.port.connectable, _set_connectable)
-
     def _is_visible(self):
         return self.length > self.MIN_LENGTH
 
@@ -165,18 +148,17 @@ class LifelineItem(Named, ElementPresentation[UML.Lifeline]):
         super().__init__(diagram, id)
 
         self._connections = diagram.connections
-        self.is_destroyed = False
 
-        self.lifetime = LifetimeItem()
+        self._lifetime = LifetimeItem()
 
-        top = self.lifetime.top
-        bottom = self.lifetime.bottom
+        top = self._lifetime.top
+        bottom = self._lifetime.bottom
 
         self._handles.append(top)
         self._handles.append(bottom)
         self.watch_handle(top)
         self.watch_handle(bottom)
-        self._ports.append(self.lifetime.port)
+        self._ports.insert(0, self._lifetime.port)
 
         self.shape = Box(
             Text(
@@ -193,9 +175,15 @@ class LifelineItem(Named, ElementPresentation[UML.Lifeline]):
         self.watch("subject.appliedStereotype.classifier.name")
         self.setup_constraints()
 
+    is_destroyed: attribute[int] = attribute("is_destroyed", int, default=False)
+
+    @property
+    def lifetime(self):
+        return self._lifetime
+
     def setup_constraints(self):
-        top = self.lifetime.top
-        bottom = self.lifetime.bottom
+        top = self._lifetime.top
+        bottom = self._lifetime.bottom
 
         # create constraints to:
         # - keep bottom handle below top handle
@@ -207,23 +195,33 @@ class LifelineItem(Named, ElementPresentation[UML.Lifeline]):
         c2 = EqualsConstraint(top.pos.x, bottom.pos.x, delta=0.0)
 
         c3 = EqualsConstraint(self._handles[SW].pos.y, top.pos.y, delta=0.0)
-        self.lifetime._c_min_length = LessThanConstraint(
+        self._lifetime._c_min_length = LessThanConstraint(
             top.pos.y, bottom.pos.y, delta=LifetimeItem.MIN_LENGTH
         )
 
-        for c in [c1, c2, c3, self.lifetime._c_min_length]:
+        for c in [c1, c2, c3, self._lifetime._c_min_length]:
             self._connections.add_constraint(self, c)
 
     def save(self, save_func):
         super().save(save_func)
-        save_func("lifetime-length", self.lifetime.length)
+        save_func("lifetime-y", float(self._lifetime.bottom.pos.y))
 
     def load(self, name, value):
-        if name == "lifetime-length":
-            self.lifetime.bottom.pos.y = self.height + float(value)
+        if name == "lifetime-y":
+            self._lifetime.bottom.pos.y = float(value)
+        elif name == "lifetime-length":
+            # For gaphor < 2.12
+            self._lifetime.bottom.pos.y = self.height + float(value)
         else:
             super().load(name, value)
 
+        # Force update the lifetime position,
+        # so message items can connect properly.
+        if name in ("top-left", "width"):
+            self._lifetime.top.pos.x = self._lifetime.bottom.pos.x = (
+                self._handles[NW].pos.x + self.width / 2
+            )
+
     def draw_lifeline(self, box, context, bounding_box):
         """Draw lifeline.
 
@@ -238,15 +236,16 @@ class LifelineItem(Named, ElementPresentation[UML.Lifeline]):
             context.hovered
             or context.focused
             or context.dropzone
-            or self.lifetime.visible
+            or self._lifetime.visible
         ):
-            bottom = self.lifetime.bottom
+            bottom = self._lifetime.bottom
             cr = context.cairo
             with cairo_state(cr):
                 cr.set_dash((7.0, 5.0), 0)
-                top = self.lifetime.top
-                cr.move_to(top.pos.x, top.pos.y)
-                cr.line_to(bottom.pos.x, bottom.pos.y)
+                x = self._handles[SW].pos.x
+                top = self._lifetime.top
+                cr.move_to(top.pos.x - x, top.pos.y)
+                cr.line_to(bottom.pos.x - x, bottom.pos.y)
                 stroke(context, dash=False)
 
             # draw destruction event
@@ -266,7 +265,7 @@ class LifelineItem(Named, ElementPresentation[UML.Lifeline]):
         calculate the lifetime. We return the minimum.
         """
         d1 = super().point(x, y)
-        top = self.lifetime.top
-        bottom = self.lifetime.bottom
+        top = self._lifetime.top
+        bottom = self._lifetime.bottom
         d2 = distance_line_point(top.pos, bottom.pos, (x, y))[0]
         return min(d1, d2)
