@@ -6,7 +6,7 @@ from typing import Iterable
 from gaphor.abc import ModelingLanguage
 from gaphor.core import gettext
 from gaphor.diagram.diagramtoolbox import DiagramType, ToolboxDefinition
-from gaphor.UML import copypaste, diagramitems, uml  # noqa F401
+from gaphor.UML import diagramitems, uml
 from gaphor.UML.toolbox import uml_diagram_types, uml_toolbox_actions
 
 
@@ -25,7 +25,4 @@ class UMLModelingLanguage(ModelingLanguage):
         yield from uml_diagram_types
 
     def lookup_element(self, name):
-        element_type = getattr(uml, name, None)
-        if not element_type:
-            element_type = getattr(diagramitems, name, None)
-        return element_type
+        return getattr(uml, name, None) or getattr(diagramitems, name, None)
