@@ -18,13 +18,15 @@ class ExtensionItem(Named, LinePresentation):
     """
 
     def __init__(self, diagram, id=None):
-        super().__init__(diagram, id)
-
-        self.shape_middle = Box(
-            Text(
-                text=lambda: stereotypes_str(self.subject),
+        super().__init__(
+            diagram,
+            id,
+            shape_middle=Box(
+                Text(
+                    text=lambda: stereotypes_str(self.subject),
+                ),
+                Text(text=lambda: self.subject.name or ""),
             ),
-            Text(text=lambda: self.subject.name or ""),
         )
 
         self.watch("subject[NamedElement].name")
