@@ -12,26 +12,27 @@ class TransitionItem(Named, LinePresentation[UML.Transition]):
     """Representation of state transition."""
 
     def __init__(self, diagram, id=None):
-        super().__init__(diagram, id)
-
-        self.shape_tail = Box(
-            Text(
-                text=lambda: stereotypes_str(self.subject),
+        super().__init__(
+            diagram,
+            id,
+            shape_middle=Text(
+                text=lambda: self.subject
+                and self.subject.guard
+                and self.subject.guard.specification
+                and f"[{self.subject.guard.specification}]"
+                or ""
+            ),
+            shape_tail=Box(
+                Text(
+                    text=lambda: stereotypes_str(self.subject),
+                ),
+                Text(text=lambda: self.subject.name or ""),
             ),
-            Text(text=lambda: self.subject.name or ""),
         )
 
         self.watch("subject[NamedElement].name")
         self.watch("subject.appliedStereotype.classifier.name")
 
-        self.shape_middle = Text(
-            text=lambda: self.subject
-            and self.subject.guard
-            and self.subject.guard.specification
-            and f"[{self.subject.guard.specification}]"
-            or ""
-        )
-
         self.watch("subject[Transition].guard[Constraint].specification")
 
         self.draw_tail = draw_arrow_tail
