@@ -6,6 +6,9 @@ operations. The regular expressions are constructed based on a series of
 attribute/operation.
 """
 
+
+import contextlib
+
 __all__ = ["parse_property", "parse_operation"]
 
 import re
@@ -27,7 +30,7 @@ mult_subpat = r"\s*(?P<has_mult>\[\s*((?P<mult_l>[0-9]+)\s*\.\.)?\s*(?P<mult_u>(
 multa_subpat = r"\s*(\[?((?P<mult_l>[0-9]+)\s*\.\.)?\s*(?P<mult_u>([0-9]+|\*))\]?)?"
 
 # Type and multiplicity (optional) ::= ':' type
-type_subpat = r"\s*(:\s*(?P<type>[a-zA-Z_]\w*( +\w+)*))?"
+type_subpat = r"\s*(:\s*(?P<type>[a-zA-Z_]\w*( +\w+| *\| *\w+| *<[\w\| ]*>)*))?"
 
 # default value (optional) ::= '=' default
 default_subpat = r"\s*(=\s*(?P<default>\S+))?"
@@ -135,19 +138,17 @@ lifeline_pat = compile(f"^{name_subpat}{type_subpat}{mult_subpat}{garbage_subpat
 
 
 def _set_visibility(el: uml.Feature, vis: str):
-    if vis == "+":
-        el.visibility = "public"
-    elif vis == "#":
+    if vis == "#":
         el.visibility = "protected"
-    elif vis == "~":
-        el.visibility = "package"
+    elif vis == "+":
+        el.visibility = "public"
     elif vis == "-":
         el.visibility = "private"
+    elif vis == "~":
+        el.visibility = "package"
     else:
-        try:
+        with contextlib.suppress(AttributeError):
             del el.visibility
-        except AttributeError:
-            pass
 
 
 def parse_attribute(el: uml.Property, s: str) -> None:
