@@ -13,15 +13,19 @@ class ExtendItem(Named, LinePresentation):
     """Use case extension relationship."""
 
     def __init__(self, diagram, id=None):
-        super().__init__(diagram, id, style={"dash-style": (7.0, 5.0)})
+        super().__init__(
+            diagram,
+            id,
+            shape_middle=Box(
+                Text(text=lambda: stereotypes_str(self.subject, (gettext("extend"),))),
+                Text(text=lambda: self.subject.name or ""),
+            ),
+            style={"dash-style": (7.0, 5.0)},
+        )
 
         self._handles[0].pos = (30, 20)
         self._handles[1].pos = (0, 0)
 
-        self.shape_middle = Box(
-            Text(text=lambda: stereotypes_str(self.subject, (gettext("extend"),))),
-            Text(text=lambda: self.subject.name or ""),
-        )
         self.watch("subject.appliedStereotype.classifier.name").watch(
             "subject[NamedElement].name"
         )
