@@ -17,8 +17,12 @@ class Service(metaclass=ABCMeta):
 
 
 class ActionProvider(metaclass=ABCMeta):
-    """An action provider is a special service that provides actions (see
-    gaphor/action.py)."""
+    """An action provider is a special service that provides actions via
+    ``@action`` decorators on its methods (see gaphor/action.py)."""
+
+    @abstractmethod
+    def __init__(self):
+        pass
 
 
 class ModelingLanguage(metaclass=ABCMeta):
