@@ -1,6 +1,6 @@
 from gaphor.core.modeling.coremodel import Comment
 from gaphor.core.modeling.diagram import Diagram, DrawContext, UpdateContext
-from gaphor.core.modeling.element import Element
+from gaphor.core.modeling.element import Element, self_and_owners
 from gaphor.core.modeling.elementfactory import ElementFactory
 from gaphor.core.modeling.event import *
 from gaphor.core.modeling.presentation import Presentation
