@@ -4,12 +4,13 @@ from __future__ import annotations
 
 import ast
 import logging
+import re
 from typing import TYPE_CHECKING, Generic, TypeVar
 
 from gaphas.item import Matrices
 
 from gaphor.core.modeling.element import Element, Id, UnlinkEvent
-from gaphor.core.modeling.event import RevertibeEvent
+from gaphor.core.modeling.event import RevertibleEvent
 from gaphor.core.modeling.properties import relation_many, relation_one
 
 if TYPE_CHECKING:
@@ -21,6 +22,10 @@ S = TypeVar("S", bound=Element)
 log = logging.getLogger(__name__)
 
 
+def literal_eval(value: str):
+    return ast.literal_eval(re.sub("\r|\n", "", value))
+
+
 class Presentation(Matrices, Element, Generic[S]):
     """This presentation is used to link the behaviors of
     `gaphor.core.modeling` and `gaphas.Item`."""
@@ -63,7 +68,7 @@ class Presentation(Matrices, Element, Generic[S]):
         return self
 
     def change_parent(self, new_parent):
-        """Change the parent and update the item's matrix so the item visualy
+        """Change the parent and update the item's matrix so the item visually
         remains in the same place."""
         old_parent = self.parent
         if new_parent is old_parent:
@@ -79,7 +84,7 @@ class Presentation(Matrices, Element, Generic[S]):
 
     def load(self, name, value):
         if name == "matrix":
-            self.matrix.set(*ast.literal_eval(value))
+            self.matrix.set(*literal_eval(value))
         elif name == "parent":
             if self.parent and self.parent is not value:
                 raise ValueError(f"Parent can not be set twice on {self}")
@@ -97,7 +102,14 @@ class Presentation(Matrices, Element, Generic[S]):
             self.parent.matrix_i2c.remove_handler(self._on_matrix_changed)
 
         if diagram := self._original_diagram:
+            connecting_items = [
+                cinfo.item
+                for cinfo in diagram.connections.get_connections(connected=self)
+            ]
+
             diagram.connections.remove_connections_to_item(self)
+            for item in connecting_items:
+                item.unlink()
             self._original_diagram = None
             super().inner_unlink(UnlinkEvent(self, diagram=diagram))
 
@@ -126,7 +138,7 @@ class Presentation(Matrices, Element, Generic[S]):
             self.handle(MatrixUpdated(self, old_value))
 
 
-class MatrixUpdated(RevertibeEvent):
+class MatrixUpdated(RevertibleEvent):
     def __init__(self, element, old_value):
         super().__init__(element)
         self.old_value = old_value
