@@ -56,7 +56,7 @@ DiagramTypes = Sequence[DiagramType]
 
 def tooliter(toolbox_actions: Sequence[Tuple[str, Sequence[ToolDef]]]):
     """Iterate toolbox items, regardless of section headers."""
-    for name, section in toolbox_actions:
+    for _name, section in toolbox_actions:
         yield from section
 
 
