@@ -8,15 +8,12 @@ from gaphor.diagram.presentation import LinePresentation
 
 
 class CommentLineItem(LinePresentation):
-    def __init__(self, id=None, model=None):
-        super().__init__(id, model, style={"dash-style": (7.0, 5.0)})
+    def __init__(self, diagram, id=None):
+        super().__init__(diagram, id, style={"dash-style": (7.0, 5.0)})
 
     def unlink(self):
-        assert self.canvas
-
-        canvas = self.canvas
-        c1 = canvas.get_connection(self.head)
-        c2 = canvas.get_connection(self.tail)
+        c1 = self._connections.get_connection(self.head)
+        c2 = self._connections.get_connection(self.tail)
         if c1 and c2:
             adapter = Connector(c1.connected, self)
             adapter.disconnect(self.head)
