@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import ast
 from dataclasses import replace
 from math import atan2
 
@@ -13,8 +12,8 @@ from gaphas.geometry import Rectangle, distance_rectangle_point
 from gaphas.solver.constraint import BaseConstraint
 
 from gaphor.core.modeling.diagram import Diagram
-from gaphor.core.modeling.event import RevertibeEvent
-from gaphor.core.modeling.presentation import Presentation, S
+from gaphor.core.modeling.event import RevertibleEvent
+from gaphor.core.modeling.presentation import Presentation, S, literal_eval
 from gaphor.core.modeling.properties import attribute
 from gaphor.core.styling import Style, merge_styles
 from gaphor.diagram.shapes import stroke
@@ -70,17 +69,16 @@ def postload_connect(item: gaphas.Item, handle: gaphas.Handle, target: gaphas.It
     connect(item, handle, target)
 
 
-class HandlePositionEvent(RevertibeEvent):
-
+class HandlePositionEvent(RevertibleEvent):
     requires_transaction = False
 
-    def __init__(self, element, index, old_value):
+    def __init__(self, element, handle, old_value):
         super().__init__(element)
-        self.index = index
+        self.handle_index = element.handles().index(handle)
         self.old_value = old_value
 
     def revert(self, target):
-        target.handles()[self.index].pos = self.old_value
+        target.handles()[self.handle_index].pos = self.old_value
         target.request_update()
 
 
@@ -92,12 +90,10 @@ class HandlePositionUpdate:
         handle.pos.remove_handler(self._on_handle_position_update)
 
     def _on_handle_position_update(self, position, old):
-        for index, handle in enumerate(self.handles()):  # type: ignore[attr-defined]
+        for handle in self.handles():  # type: ignore[attr-defined]
             if handle.pos is position:
+                self.handle(HandlePositionEvent(self, handle, old))  # type: ignore[attr-defined]
                 break
-        else:
-            return
-        self.handle(HandlePositionEvent(self, index, old))  # type: ignore[attr-defined]
 
 
 # Note: the official documentation is using the terms "Shape" and "Edge" for element and line.
@@ -129,12 +125,15 @@ class ElementPresentation(gaphas.Element, HandlePositionUpdate, Presentation[S])
     def port_side(self, port):
         return self._port_sides[self._ports.index(port)]
 
-    def _set_shape(self, shape):
+    @property
+    def shape(self):
+        return self._shape
+
+    @shape.setter
+    def shape(self, shape):
         self._shape = shape
         self.request_update()
 
-    shape = property(lambda s: s._shape, _set_shape)
-
     def update_shapes(self, event=None):
         """Updating the shape configuration, e.g. when extra elements have to
         be drawn or when styling changes."""
@@ -163,15 +162,15 @@ class ElementPresentation(gaphas.Element, HandlePositionUpdate, Presentation[S])
 
     def load(self, name, value):
         if name == "top-left":
-            pos = ast.literal_eval(value)
+            pos = literal_eval(value)
             self._handles[0].pos = pos
             # Also adjust bottom-right handle to keep width and height intact
             self._handles[2].pos.x += pos[0]
             self._handles[2].pos.y += pos[1]
         elif name == "width":
-            self.width = ast.literal_eval(value)
+            self.width = literal_eval(value)
         elif name == "height":
-            self.height = ast.literal_eval(value)
+            self.height = literal_eval(value)
         else:
             super().load(name, value)
 
@@ -197,17 +196,19 @@ class LinePresentation(gaphas.Line, HandlePositionUpdate, Presentation[S]):
         self,
         diagram: Diagram,
         id=None,
-        style: Style = {},
+        style: Style | None = None,
         shape_head=None,
         shape_middle=None,
         shape_tail=None,
     ):
+        if style is None:
+            style = {}
         super().__init__(connections=diagram.connections, diagram=diagram, id=id)  # type: ignore[call-arg]
 
-        self.style = style
-        self.shape_head = shape_head
-        self.shape_middle = shape_middle
-        self.shape_tail = shape_tail
+        self._style = style
+        self._shape_head = shape_head
+        self._shape_middle = shape_middle
+        self._shape_tail = shape_tail
 
         self.fuzziness = 2
         self._shape_head_rect = None
@@ -225,6 +226,22 @@ class LinePresentation(gaphas.Line, HandlePositionUpdate, Presentation[S]):
     orthogonal: attribute[int] = attribute("orthogonal", int, 0)
     horizontal: attribute[int] = attribute("horizontal", int, 0)
 
+    @property
+    def shape_head(self):
+        return self._shape_head
+
+    @property
+    def shape_middle(self):
+        return self._shape_middle
+
+    @property
+    def shape_tail(self):
+        return self._shape_tail
+
+    @property
+    def style(self):
+        return self._style
+
     @property
     def middle_shape_size(self) -> Rectangle:
         return self._shape_middle_rect
@@ -245,9 +262,9 @@ class LinePresentation(gaphas.Line, HandlePositionUpdate, Presentation[S]):
                 return Rectangle(x, y, *size)
 
         points = [h.pos for h in self.handles()]
-        self._shape_head_rect = shape_bounds(self.shape_head, TextAlign.LEFT)
-        self._shape_middle_rect = shape_bounds(self.shape_middle, TextAlign.CENTER)
-        self._shape_tail_rect = shape_bounds(self.shape_tail, TextAlign.RIGHT)
+        self._shape_head_rect = shape_bounds(self._shape_head, TextAlign.LEFT)
+        self._shape_middle_rect = shape_bounds(self._shape_middle, TextAlign.CENTER)
+        self._shape_tail_rect = shape_bounds(self._shape_tail, TextAlign.RIGHT)
 
     def point(self, x, y):
         """Given a point (x, y) return the distance to the diagram item."""
@@ -281,9 +298,9 @@ class LinePresentation(gaphas.Line, HandlePositionUpdate, Presentation[S]):
         stroke(context)
 
         for shape, rect in (
-            (self.shape_head, self._shape_head_rect),
-            (self.shape_middle, self._shape_middle_rect),
-            (self.shape_tail, self._shape_tail_rect),
+            (self._shape_head, self._shape_head_rect),
+            (self._shape_middle, self._shape_middle_rect),
+            (self._shape_tail, self._shape_tail_rect),
         ):
             if shape:
                 shape.draw(context, rect)
@@ -303,7 +320,7 @@ class LinePresentation(gaphas.Line, HandlePositionUpdate, Presentation[S]):
 
     def load(self, name, value):
         if name == "points":
-            points = ast.literal_eval(value)
+            points = literal_eval(value)
             for _ in range(len(points) - 2):
                 h = Handle((0, 0))
                 self._handles.insert(1, h)
@@ -366,11 +383,13 @@ class AttachedPresentation(HandlePositionUpdate, Presentation[S]):
     E.g. ports, pins and parameter nodes.
     """
 
-    def __init__(self, diagram, id=None, width=16, height=16):
+    def __init__(self, diagram, id=None, shape=None, width=16, height=16):
         super().__init__(diagram, id)
         self._connections = diagram.connections
         self._width_constraints = []
         self._height_constraints = []
+        self._last_connected_side = None
+        self._shape = shape
 
         handle = self._handle = Handle(strength=gaphas.solver.STRONG, connectable=True)
         self.watch_handle(handle)
@@ -400,9 +419,6 @@ class AttachedPresentation(HandlePositionUpdate, Presentation[S]):
         self.width = width
         self.height = height
 
-        self._shape = None
-        self._last_connected_side = None
-
     @property
     def width(self) -> float:
         c = self._corners
@@ -490,7 +506,8 @@ class AttachedPresentation(HandlePositionUpdate, Presentation[S]):
         return distance_rectangle_point(self.dimensions(), (x, y))
 
     def draw(self, context):
-        self.shape.draw(context, self.dimensions())
+        if self.shape:
+            self.shape.draw(context, self.dimensions())
 
     def dimensions(self):
         top_left, _, bottom_right, _ = self._corners
@@ -507,7 +524,7 @@ class AttachedPresentation(HandlePositionUpdate, Presentation[S]):
 
     def load(self, name, value):
         if name == "point":
-            self._handle.pos = ast.literal_eval(value)
+            self._handle.pos = literal_eval(value)
         elif name == "connection":
             self._load_connection = value
         else:
