@@ -71,10 +71,10 @@ class ModelingLanguageService(Service, ActionProvider, ModelingLanguage):
         return next(
             filter(
                 None,
-                map(
-                    lambda provider: provider.lookup_element(name),
-                    self._modeling_languages.values(),
-                ),
+                [
+                    provider.lookup_element(name)
+                    for provider in self._modeling_languages.values()
+                ],
             ),
             None,
         )
