@@ -3,8 +3,9 @@
 from __future__ import annotations
 
 import logging
+import tempfile
 from pathlib import Path
-from queue import Queue
+from typing import Callable
 
 from gaphas.decorators import g_async
 from gi.repository import Gtk
@@ -24,6 +25,7 @@ from gaphor.event import (
     SessionShutdownRequested,
 )
 from gaphor.storage import storage
+from gaphor.storage.mergeconflict import split
 from gaphor.storage.parser import MergeConflictDetected
 from gaphor.ui.errorhandler import error_handler
 from gaphor.ui.filedialog import GAPHOR_FILTER, save_file_dialog
@@ -61,7 +63,7 @@ def load_default_model(element_factory):
         model.name = gettext("New model")
         diagram = element_factory.create(Diagram)
         diagram.element = model
-        diagram.name = gettext("main")
+        diagram.name = gettext("New diagram")
     element_factory.model_ready()
 
 
@@ -77,7 +79,7 @@ class FileManager(Service, ActionProvider):
         self.element_factory = element_factory
         self.modeling_language = modeling_language
         self.main_window = main_window
-        self._filename = None
+        self._filename: Path | None = None
 
         event_manager.subscribe(self._on_session_shutdown_request)
         event_manager.subscribe(self._on_session_created)
@@ -88,7 +90,7 @@ class FileManager(Service, ActionProvider):
         self.event_manager.unsubscribe(self._on_session_created)
 
     @property
-    def filename(self):
+    def filename(self) -> Path | None:
         """Return the current file name.
 
         This method is used by the filename property.
@@ -96,53 +98,61 @@ class FileManager(Service, ActionProvider):
         return self._filename
 
     @filename.setter
-    def filename(self, filename):
+    def filename(self, filename: Path | str | None):
         """Sets the current file name.
 
-        This method is used by the filename property. Setting the
-        current filename will update the recent file list.
+        This method is used by the filename property.
         """
 
         if filename != self._filename:
             self._filename = Path(filename) if filename else None
 
-    def load(self, filename):
+    def load(self, filename: Path, on_load_done: Callable[[], None] | None = None):
         """Load the Gaphor model from the supplied file name.
 
-        A status window displays the loading progress.  The load
+        A status window displays the loading progress. The load
         generator updates the progress queue.  The loader is passed to a
-        GIdleThread which executes the load generator.  If loading is
+        GIdleThread which executes the load generator. If loading is
         successful, the filename is set.
         """
         # First claim file name, so any other files will be opened in a different session
-        self.filename = Path(filename)
-        queue: Queue[int] = Queue(0)
-        status_window = None
+        self.filename = filename
 
-        @g_async()
-        def create_status_window():
-            nonlocal status_window
-            status_window = StatusWindow(
-                gettext("Loading…"),
-                gettext("Loading model from {filename}").format(filename=filename),
-                parent=self.parent_window,
-                queue=queue,
-            )
+        status_window = StatusWindow(
+            gettext("Loading…"),
+            gettext("Loading model from {filename}").format(filename=filename),
+            parent=self.parent_window,
+        )
 
         def done():
-            if status_window:
-                status_window.destroy()
+            status_window.destroy()
+            if on_load_done:
+                on_load_done()
+            else:
+                self.event_manager.handle(ModelLoaded(self, filename))
 
-        create_status_window()
-        self._load_async(filename, queue, done)
+        self._load_async(filename, status_window.progress, done)
 
     def load_template(self, template):
         storage.load(template, self.element_factory, self.modeling_language)
         self.event_manager.handle(ModelLoaded(self))
 
-    def _load_async(self, filename: Path, queue=None, done=None):
+    def _load_async(
+        self, filename: Path, progress: Callable[[int], None] | None = None, done=None
+    ):
         assert isinstance(filename, Path)
 
+        def open_model(encoding):
+            with open(filename, encoding=encoding) as file_obj:
+                for percentage in storage.load_generator(
+                    file_obj,
+                    self.element_factory,
+                    self.modeling_language,
+                ):
+                    if progress:
+                        progress(percentage)
+                    yield percentage
+
         # Use low prio, so screen updates do happen
         @g_async()
         def async_loader():
@@ -152,27 +162,37 @@ class FileManager(Service, ActionProvider):
                 except UnicodeDecodeError:
                     # try to load without encoding, for older models saved on windows
                     yield from open_model(encoding=None)
-
-                self.event_manager.handle(ModelLoaded(self, filename))
             except MergeConflictDetected:
                 self.filename = None
-                error_handler(
-                    message=gettext("Merge conflict in model “{filename}”.").format(
-                        filename=filename
-                    ),
-                    secondary_message=gettext(
-                        "It looks like this model file contains a merge conflict."
-                    ),
-                    window=self.parent_window,
-                    close=lambda: self.event_manager.handle(SessionShutdown(self)),
-                )
-                # For now load the default model until we allow users to resolve the merge conflict.
-                load_default_model(self.element_factory)
+                if Gtk.get_major_version() == 3:
+                    error_handler(
+                        message=gettext("Merge conflict in model “{filename}”.").format(
+                            filename=filename.name
+                        ),
+                        secondary_message=gettext(
+                            "It looks like this model file contains a merge conflict."
+                        ),
+                        window=self.parent_window,
+                        close=lambda: self.event_manager.handle(SessionShutdown(self)),
+                    )
+                    # For now load the default model until we allow users to resolve the merge conflict.
+                    load_default_model(self.element_factory)
+                else:
+
+                    def handle_merge_conflict(answer):
+                        if answer == "cancel":
+                            self.event_manager.handle(SessionShutdown(self))
+                        else:
+                            self.resolve_merge_conflict(filename, resolution=answer)
+
+                    resolve_merge_conflict_dialog(
+                        self.parent_window, filename, handle_merge_conflict
+                    )
             except Exception:
                 self.filename = None
                 error_handler(
                     message=gettext("Unable to open model “{filename}”.").format(
-                        filename=filename
+                        filename=filename.name
                     ),
                     secondary_message=gettext(
                         "This file does not contain a valid Gaphor model."
@@ -184,20 +204,33 @@ class FileManager(Service, ActionProvider):
                 if done:
                     done()
 
-        def open_model(encoding):
-            with open(filename, encoding=encoding) as file_obj:
-                for percentage in storage.load_generator(
-                    file_obj,
-                    self.element_factory,
-                    self.modeling_language,
-                ):
-                    if queue:
-                        queue.put(percentage)
-                    yield percentage
-
         for _ in async_loader():
             pass
 
+    def resolve_merge_conflict(self, filename: Path, resolution: str):
+        temp_dir = tempfile.TemporaryDirectory()
+        current_filename = Path(temp_dir.name) / f"current-{filename.name}"
+        incoming_filename = Path(temp_dir.name) / f"incoming-{filename.name}"
+        with (
+            filename.open(encoding="utf-8") as f,
+            current_filename.open("w+", encoding="utf-8") as current_file,
+            incoming_filename.open("w+", encoding="utf-8") as incoming_file,
+        ):
+            split(f, current_file, incoming_file)
+
+        def done():
+            nonlocal temp_dir
+            temp_dir.cleanup()
+            self.filename = filename
+            self.event_manager.handle(ModelLoaded(self, filename, modified=True))
+
+        if resolution == "current":
+            self.load(current_filename, on_load_done=done)
+        elif resolution == "incoming":
+            self.load(incoming_filename, on_load_done=done)
+        else:
+            raise RuntimeError(f"Unknown resolution for merge conflict: {resolution}")
+
     def save(self, filename, on_save_done=None):
         """Save the current UML model to the specified file name.
 
@@ -210,12 +243,10 @@ class FileManager(Service, ActionProvider):
         if not filename or (filename.exists() and not filename.is_file()):
             return
 
-        queue: Queue[int] = Queue()
         status_window = StatusWindow(
             gettext("Saving…"),
             gettext("Saving model to {filename}").format(filename=filename),
             parent=self.parent_window,
-            queue=queue,
         )
 
         @g_async()
@@ -223,7 +254,7 @@ class FileManager(Service, ActionProvider):
             try:
                 with filename.open("w", encoding="utf-8") as out:
                     for percentage in storage.save_generator(out, self.element_factory):
-                        queue.put(percentage)
+                        status_window.progress(percentage)
                         yield
 
                 self.filename = filename
@@ -265,12 +296,9 @@ class FileManager(Service, ActionProvider):
     @action(name="file-save-as", shortcut="<Primary><Shift>s")
     def action_save_as(self):
         """Save the model in the element_factory by allowing the user to select
-        a file name.
+        a file name."""
 
-        Returns True if the saving actually happened.
-        """
-
-        save_file_dialog(
+        return save_file_dialog(
             gettext("Save Gaphor Model As"),
             self.save,
             parent=self.parent_window,
@@ -326,6 +354,30 @@ class FileManager(Service, ActionProvider):
             confirm_shutdown()
 
 
+def resolve_merge_conflict_dialog(window: Gtk.Window, filename, handler) -> None:
+    dialog = Adw.MessageDialog.new(
+        window,
+        gettext("Resolve Merge Conflict?"),
+    )
+    dialog.set_body(
+        gettext(
+            "The model you are opening contains a merge conflict. Do you want to open the current model or the incoming change to the model?"
+        )
+    )
+    dialog.add_response("cancel", gettext("Cancel"))
+    dialog.add_response("current", gettext("Open Current"))
+    dialog.add_response("incoming", gettext("Open Incoming"))
+    dialog.set_close_response("cancel")
+
+    def response(dialog, answer):
+        dialog.set_transient_for(None)
+        dialog.destroy()
+        handler(answer)
+
+    dialog.connect("response", response)
+    dialog.show()
+
+
 def save_changes_before_closing_dialog(window: Gtk.Window, handler) -> None:
     title = gettext("Save Changes?")
     body = gettext(
@@ -363,6 +415,9 @@ def save_changes_before_closing_dialog(window: Gtk.Window, handler) -> None:
         dialog.set_close_response("cancel")
 
     def response(dialog, answer):
+        # Unset transient window: it can cause crashes on flatpak
+        # when all windows are destroyed at once.
+        dialog.set_transient_for(None)
         dialog.destroy()
         handler(answer)
 
