@@ -2,29 +2,35 @@ from __future__ import annotations
 
 import sys
 
-from gi.repository import Gdk, GLib, GObject, Gtk
+from gi.repository import Gdk, Gio, GLib, GObject, Gtk
 
 from gaphor import UML
 from gaphor.abc import ActionProvider
 from gaphor.action import action
 from gaphor.core import event_handler
 from gaphor.core.modeling import (
+    DerivedAdded,
+    DerivedDeleted,
     DerivedSet,
     Diagram,
     Element,
     ElementCreated,
     ElementDeleted,
+    ElementUpdated,
     ModelFlushed,
     ModelReady,
 )
-from gaphor.core.modeling.event import AttributeUpdated, DerivedAdded, DerivedDeleted
 from gaphor.diagram.tools.dnd import ElementDragData
 from gaphor.i18n import gettext, translated_ui_string
 from gaphor.transaction import Transaction
 from gaphor.ui.abc import UIComponent
 from gaphor.ui.actiongroup import create_action_group
 from gaphor.ui.event import DiagramOpened, DiagramSelectionChanged, ElementOpened
-from gaphor.ui.namespace import diagram_name_for_type, popup_model
+from gaphor.ui.namespace import (
+    create_diagram_types_model,
+    diagram_name_for_type,
+    popup_model,
+)
 from gaphor.ui.namespacemodel import change_owner
 from gaphor.ui.treemodel import (
     RelationshipItem,
@@ -66,17 +72,22 @@ class TreeComponent(UIComponent, ActionProvider):
         self.sorter = Gtk.CustomSorter.new(tree_item_sort)
         tree_sorter = Gtk.TreeListRowSorter.new(self.sorter)
         sort_model = Gtk.SortListModel.new(tree_model, tree_sorter)
-        self.selection = Gtk.SingleSelection.new(sort_model)
+        self.selection = Gtk.MultiSelection.new(sort_model)
 
         factory = Gtk.SignalListItemFactory.new()
         factory.connect(
-            "setup", list_item_factory_setup, self.event_manager, self.modeling_language
+            "setup",
+            list_item_factory_setup,
+            self.selection,
+            self.event_manager,
+            self.modeling_language,
         )
         self.tree_view = Gtk.ListView.new(self.selection, factory)
         self.tree_view.set_vexpand(True)
 
         def list_view_activate(list_view, position):
-            list_view.activate_action("tree-view.open", None)
+            element = self.selection.get_item(position).get_item().element
+            self.open_element(element)
 
         self.tree_view.connect("activate", list_view_activate)
 
@@ -86,7 +97,13 @@ class TreeComponent(UIComponent, ActionProvider):
 
         action_group, shortcuts = create_action_group(self, "tree-view")
         scrolled_window.insert_action_group("tree-view", action_group)
-        self.tree_view.add_controller(create_popup_controller(shortcuts))
+        self.tree_view.add_controller(create_shortcut_controller(shortcuts))
+
+        self.tree_view.add_controller(
+            create_popup_controller(
+                self.tree_view, self.selection, self.modeling_language
+            )
+        )
 
         self.search_bar = create_search_bar(SearchEngine(self.model, self.tree_view))
 
@@ -112,20 +129,26 @@ class TreeComponent(UIComponent, ActionProvider):
     def select_element(self, element: Element) -> int | None:
         return select_element(self.tree_view, element)
 
+    def get_selected_elements(self) -> list[Element]:
+        assert self.model
+        return get_selected_elements(self.selection)
+
     def get_selected_element(self) -> Element | None:
         assert self.model
-        if tree_item := self.selection.get_selected_item():
-            return tree_item.get_item().element  # type: ignore[no-any-return]
-        return None
+        return next(iter(self.get_selected_elements()), None)
 
-    @action(name="tree-view.open")
-    def tree_view_open_selected(self):
-        element = self.get_selected_element()
+    def open_element(self, element):
+        assert element
         if isinstance(element, Diagram):
             self.event_manager.handle(DiagramOpened(element))
         else:
             self.event_manager.handle(ElementOpened(element))
 
+    @action(name="tree-view.open")
+    def tree_view_open_selected(self):
+        element = self.get_selected_element()
+        self.open_element(element)
+
     @action(name="tree-view.show-in-diagram")
     def tree_view_show_in_diagram(self, diagram_id: str) -> None:
         element = self.element_factory.lookup(diagram_id)
@@ -133,7 +156,7 @@ class TreeComponent(UIComponent, ActionProvider):
 
     @action(name="tree-view.rename", shortcut="F2")
     def tree_view_rename_selected(self):
-        if row_item := self.selection.get_selected_item():
+        if row_item := get_first_selected_item(self.selection):
             tree_item: TreeItem = row_item.get_item()
             GLib.timeout_add(START_EDIT_DELAY, tree_item.start_editing)
 
@@ -156,22 +179,20 @@ class TreeComponent(UIComponent, ActionProvider):
     @action(name="tree-view.create-package")
     def tree_view_create_package(self):
         element = self.get_selected_element()
-        assert isinstance(element, UML.Package)
         with Transaction(self.event_manager):
             package = self.element_factory.create(UML.Package)
-            package.package = element
-            package.name = (
-                gettext("{name} package").format(name=element.name)
-                if element
-                else gettext("New model")
-            )
+            if isinstance(element, UML.Package):
+                package.package = element
+                package.name = gettext("{name} package").format(name=element.name)
+            else:
+                package.name = gettext("New package")
         self.select_element(package)
         self.tree_view_rename_selected()
 
     @action(name="tree-view.delete", shortcut="Delete")
     def tree_view_delete(self):
-        if element := self.get_selected_element():
-            with Transaction(self.event_manager):
+        with Transaction(self.event_manager):
+            for element in self.get_selected_elements():
                 element.unlink()
 
     @action(name="win.search", shortcut="<Primary>f")
@@ -204,8 +225,8 @@ class TreeComponent(UIComponent, ActionProvider):
         self.model.add_element(element)
         self.select_element(element)
 
-    @event_handler(AttributeUpdated)
-    def on_attribute_changed(self, event: AttributeUpdated):
+    @event_handler(ElementUpdated)
+    def on_attribute_changed(self, event: ElementUpdated):
         self.model.sync(event.element)
         self.sorter.changed(Gtk.SorterChange.DIFFERENT)
 
@@ -232,45 +253,50 @@ class SearchEngine:
         self.model = model
         self.tree_view = tree_view
         self.selection = self.tree_view.get_model()
-        self.selected_changed_id = self.selection.connect(
-            "selection-changed", self.on_selection_changed
-        )
-        self.selected_item = None
-
-    def on_selection_changed(self, selection, position, n_items):
-        self.reset()
-
-    def reset(self):
-        self.selected_item = None
 
     def text_changed(self, search_text):
-        if not self.selected_item:
-            self.selected_item = self.selection.get_selected_item()
+        selected_item = get_first_selected_item(self.selection)
         if next_item := search(
             search_text,
             sorted_tree_walker(
                 self.model,
-                start_tree_item=self.selected_item and self.selected_item.get_item(),
+                start_tree_item=selected_item and selected_item.get_item(),
                 from_current=True,
             ),
         ):
-            self.selection.handler_block(self.selected_changed_id)
             select_element(self.tree_view, next_item.element)
-            self.selection.handler_unblock(self.selected_changed_id)
 
     def search_next(self, search_text):
+        selected_item = get_first_selected_item(self.selection)
         if next_item := search(
             search_text,
             sorted_tree_walker(
                 self.model,
-                start_tree_item=self.selection.get_selected_item().get_item(),
+                start_tree_item=selected_item and selected_item.get_item(),
                 from_current=False,
             ),
         ):
             select_element(self.tree_view, next_item.element)
 
 
-def select_element(tree_view: Gtk.ListView, element: Element) -> int | None:
+def get_selected_elements(selection: Gtk.SelectionModel) -> list[Element]:
+    bitset = selection.get_selection()
+    return [
+        e
+        for n in range(bitset.get_size())
+        if (e := selection.get_item(bitset.get_nth(n)).get_item().element)
+    ]
+
+
+def get_first_selected_item(selection):
+    bitset = selection.get_selection()
+    pos = bitset.get_nth(0)
+    return selection.get_item(pos)
+
+
+def select_element(
+    tree_view: Gtk.ListView, element: Element, unselect_rest=True
+) -> int | None:
     def expand_up_to_element(element, expand=False) -> int | None:
         if not element:
             return 0
@@ -290,7 +316,7 @@ def select_element(tree_view: Gtk.ListView, element: Element) -> int | None:
     selection = tree_view.get_model()
     pos = expand_up_to_element(element)
     if pos is not None:
-        selection.set_selected(pos)
+        selection.select_item(pos, unselect_rest)
         tree_view.activate_action("list.scroll-to-item", GLib.Variant.new_uint32(pos))
     return pos
 
@@ -299,15 +325,11 @@ def create_search_bar(search_engine: SearchEngine):
     def on_search_changed(entry):
         search_engine.text_changed(entry.get_text())
 
-    def on_stop_search(_entry):
-        search_engine.reset()
-
     def on_search_next(entry):
         search_engine.search_next(entry.get_text())
 
     search_entry = Gtk.SearchEntry.new()
     search_entry.connect("search-changed", on_search_changed)
-    search_entry.connect("stop-search", on_stop_search)
     search_entry.connect("activate", on_search_next)
     search_entry.connect("next-match", on_search_next)
     search_bar = Gtk.SearchBar.new()
@@ -318,13 +340,51 @@ def create_search_bar(search_engine: SearchEngine):
     return search_bar
 
 
-def create_popup_controller(shortcuts):
+def create_shortcut_controller(shortcuts):
     ctrl = Gtk.ShortcutController.new_for_model(shortcuts)
     ctrl.set_scope(Gtk.ShortcutScope.LOCAL)
     return ctrl
 
 
-def list_item_factory_setup(_factory, list_item, event_manager, modeling_language):
+def create_popup_controller(tree_view, selection, modeling_language):
+    menu = None
+
+    def on_show_popup(ctrl, n_press, x, y):
+        nonlocal menu
+        selection.unselect_item(selection.get_selected())
+        if not menu:
+            menu = Gtk.PopoverMenu.new_from_model(
+                toplevel_popup_model(modeling_language)
+            )
+            menu.set_parent(tree_view)
+            menu.set_has_arrow(False)
+
+        gdk_rect = Gdk.Rectangle()
+        gdk_rect.x = x
+        gdk_rect.y = y
+        gdk_rect.width = gdk_rect.height = 1
+
+        menu.set_pointing_to(gdk_rect)
+        menu.popup()
+
+    ctrl = Gtk.GestureClick.new()
+    ctrl.set_button(Gdk.BUTTON_SECONDARY)
+    ctrl.connect("pressed", on_show_popup)
+    return ctrl
+
+
+def toplevel_popup_model(modeling_language) -> Gio.Menu:
+    model = create_diagram_types_model(modeling_language)
+
+    part = Gio.Menu.new()
+    part.append(gettext("New _Package"), "tree-view.create-package")
+    model.prepend_section(None, part)
+    return model
+
+
+def list_item_factory_setup(
+    _factory, list_item, selection, event_manager, modeling_language
+):
     builder = Gtk.Builder()
     builder.set_current_object(list_item)
     builder.extend_with_template(
@@ -334,6 +394,7 @@ def list_item_factory_setup(_factory, list_item, event_manager, modeling_languag
         -1,
     )
     row = builder.get_object("row")
+    row.menu = None
 
     def on_show_popup(ctrl, n_press, x, y):
         list_item.get_child().activate_action(
@@ -345,12 +406,16 @@ def list_item_factory_setup(_factory, list_item, event_manager, modeling_languag
             ),
         )
         element = list_item.get_item().get_item().element
+        if row.menu:
+            # Clean menu only when we want to create a new one.
+            row.menu.unparent()
+            row.menu = None
         if element:
-            menu = Gtk.PopoverMenu.new_from_model(
+            row.menu = Gtk.PopoverMenu.new_from_model(
                 popup_model(element, modeling_language)
             )
-            menu.set_parent(row)
-            menu.popup()
+            row.menu.set_parent(row)
+            row.menu.popup()
 
     ctrl = Gtk.GestureClick.new()
     ctrl.set_button(Gdk.BUTTON_SECONDARY)
@@ -360,7 +425,7 @@ def list_item_factory_setup(_factory, list_item, event_manager, modeling_languag
     if sys.platform != "darwin":
         drag_source = Gtk.DragSource.new()
         drag_source.set_actions(Gdk.DragAction.MOVE | Gdk.DragAction.COPY)
-        drag_source.connect("prepare", list_item_drag_prepare, list_item)
+        drag_source.connect("prepare", list_item_drag_prepare, list_item, selection)
         drag_source.connect("drag-begin", list_item_drag_begin, list_item)
         row.add_controller(drag_source)
 
@@ -418,20 +483,29 @@ def list_item_factory_setup(_factory, list_item, event_manager, modeling_languag
 
 
 def list_item_drag_prepare(
-    source: Gtk.DragSource, x: int, y: int, list_item: Gtk.ListItem
+    source: Gtk.DragSource,
+    x: int,
+    y: int,
+    list_item: Gtk.ListItem,
+    selection: Gtk.SelectionModel,
 ) -> Gdk.ContentProvider | None:
-    tree_item = list_item.get_item().get_item()
-    if isinstance(tree_item, RelationshipItem):
+    elements = get_selected_elements(selection)
+    under_cursor = list_item.get_item().get_item().element
+
+    if not elements:
+        elements = [under_cursor]
+
+    if under_cursor not in elements:
         return None
 
-    v = GObject.Value(
-        ElementDragData.__gtype__, ElementDragData(element=tree_item.element)
-    )
+    v = GObject.Value(ElementDragData.__gtype__, ElementDragData(elements=elements))
     return Gdk.ContentProvider.new_for_value(v)
 
 
 def list_item_drag_begin(
-    source: Gtk.DragSource, drag: Gdk.Drag, list_item: Gtk.ListItem
+    source: Gtk.DragSource,
+    drag: Gdk.Drag,
+    list_item: Gtk.ListItem,
 ) -> None:
     tree_item = list_item.get_item().get_item()
     display = Gdk.Display.get_default()
@@ -484,7 +558,6 @@ def list_item_drop_drop(
 ) -> Gdk.DragAction:
     list_item_drop_leave(target, list_item)
 
-    element = value.element
     tree_item = list_item.get_item().get_item()
     dest_element = tree_item.element
     if y < 4:
@@ -494,9 +567,9 @@ def list_item_drop_drop(
         # This view is concerned with owner relationships.
         # Let's check if the owner relation has actually changed,
         # Otherwise roll back, to not confuse the user.
-        if not change_owner(dest_element, element):
-            tx.rollback()
-        else:
-            return True
+        for element in value.elements:
+            if not change_owner(dest_element, element):
+                tx.rollback()
+                return False
 
-    return False
+    return True
